@@ -8,7 +8,7 @@ package Syntax::Keyword::Try;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -21,7 +21,7 @@ C<Syntax::Keyword::Try> - a C<try/catch/finally> syntax for perl
 
 =head1 SYNOPSIS
 
- use Syntax::Keyword::Try 'try';
+ use Syntax::Keyword::Try;
 
  sub foo
  {
@@ -75,12 +75,7 @@ circumstance only the C<eval> itself would return, not the entire function.
 
 The body of a C<try {}> block may contain loop control expressions (C<redo>,
 C<next>, C<last>) which will have their usual effect on any loops that the
-C<try {}> block is contained by. As of the current implementation however,
-these will result in a warning
-
- Exiting eval via redo at FILE line LINE.
-
-The use of C<no warnings 'exiting'> can avoid this.
+C<try {}> block is contained by.
 
 The parsing rules for the set of statements (the C<try> block and its
 associated C<catch> and C<finally>) are such that they are parsed as a self-
@@ -158,14 +153,6 @@ anonymous function which is then immediately executed:
     catch { return "failure" }
  }->();
 
-=item *
-
-Suppress the C<exiting> warning when using loop control systems in the
-C<try {}> block. This is sligtly nontrivial because an inplace replacement of
-an C<OP_LAST> to an C<OP_LINESEQ> containing the new hints COP isn't possible
-due to differing op types. It will require more careful re-splicing into
-parent trees.
-
 =back
 
 =cut
@@ -279,6 +266,8 @@ sub import_into
    my $class = shift;
    my ( $caller, @syms ) = @_;
 
+   @syms or @syms = qw( try );
+
    my %syms = map { $_ => 1 } @syms;
    $^H{"Syntax::Keyword::Try/try"}++ if delete $syms{try};
 
